<?php
namespace Controllers;

use Core, Models;

class ContratosController extends Core\Controller {

   public function __construct() {

      $this->isLogged();            //verifica se está logado, estou vendo isso no Core/Controller
      $this->verificaPermissao();    //verifica se tenho permissao, estou vendo isso no Core/Controller
   }

   //função responsável por abrir a página principal dos contratos
   public function index(){         
      $template = new Models\TemplateContrato();

      $dados = array();      
      $dados['registros'] = $template->listaTemplates();
      
      //Carrega a página principal do cadastro de contratos
      $this->loadView('contratos', $dados); 
   }

   //Função para adicionar um novo contrato
   public function novoTemplate($error=NULL){ 
      $dados = array();

      //Verifica se a variavel error foi inicializada
      if(isset($error))
         $dados['error'] = $error;
      else
         $dados['error'] = NULL;

      //Envia para a view os parametros necessários
      $dados['atualiza'] = 'N';
      
      //Carrega a view responsável por cadastrar um novo contrato  
      $this->loadView('addContrato', $dados);    
   }

   //Função para editar um template de um contrato
   public function editaTemplate($idTemplate,$error=NULL){ 
      $template = new Models\TemplateContrato();
      $dados = array();

      //Verifica se a variavel error foi inicializada
      if(isset($error))
         $dados['error'] = $error;
      else
         $dados['error'] = NULL;

      //Envia para a view os parametros necessários
      $dados['template'] = $template->buscaTemplatePorId($idTemplate);
      $dados['atualiza'] = 'S';
      
      //Carrega a view responsável por cadastrar um novo contrato  
      $this->loadView('addContrato', $dados);    
   }

   //Função para salvar os dados do template do contrato
   public function salvaTemplateContrato(){
      $template = new Models\TemplateContrato();

      //Prepara o upload do arquivo de template
      $extensao = substr($_POST['nomearquivo'],-4);

      if($extensao == 'docx'){

         //Verifica se o sistema deve proceder com a atualização ou inserção dos dados
         if($_POST['atualizacao'] == 'S'){

            //verifica se é necessário atualizar o arquivo
            if($_POST['nomefile'] != $_POST['nomearquivo']){
               
               //Apaga o arquivo
               $this->ApagaArquivoTemplate($_POST['nomefile']);

               //Recebe o arquivo via POST
               $arquivoTemplate = $_FILES['arquivo']['tmp_name'];

               //Renomeia o arquivo
               $geraBytes    = random_bytes(7);
               $nomeTemplate = bin2hex($geraBytes).'.docx';        

               //Tenta fazer o upload do arquivo
               if(move_uploaded_file($arquivoTemplate,"assets/templateContratos/".$nomeTemplate)){

                  //Cria o array com os dados do template do contrato para serem salvos na base de dados
                  $dadosTemplate = [
                     'DESCRICAO'       => $_POST['descricao'],
                     'VIGENCIA_INICIO' => $_POST['vigenciaInicio'],
                     'VIGENCIA_FIM'    => $_POST['vigenciaFim'] == '' ? NULL : $_POST['vigenciaFim'],
                     'NOME_TEMPLATE'   => $nomeTemplate,
                     'ATIVO'           => isset($_POST['ativo']) ? 1 : 0 
                  ];
                  
                  //Insere os dados na base e redireciona para a próxima página
                  if($template->editaTemplateContrato($dadosTemplate,$_POST['idTemplate']))
                     header("Location: ".BASE_URL.'/contratos');
                  else
                     header("Location: ".BASE_URL.'/contratos/novoTemplate/EBD');
               }else{
               
                  header("Location: ".BASE_URL.'/contratos/novoTemplate/UP');   
               }
            } else {
               //Cria o array com os dados do template do contrato para serem salvos na base de dados
               $dadosTemplate = [
                  'DESCRICAO'       => $_POST['descricao'],
                  'VIGENCIA_INICIO' => $_POST['vigenciaInicio'],
                  'VIGENCIA_FIM'    => $_POST['vigenciaFim'] == '' ? NULL : $_POST['vigenciaFim'],
                  'NOME_TEMPLATE'   => $_POST['nomefile'],
                  'ATIVO'           => isset($_POST['ativo']) ? 1 : 0 
               ];

               //Insere os dados na base e redireciona para a próxima página
               if($template->editaTemplateContrato($dadosTemplate,$_POST['idTemplate']))
                  header("Location: ".BASE_URL.'/contratos');
               else
                  header("Location: ".BASE_URL.'/contratos/editaTemplate/'.$idTemplate.'/EBD');
            }                                             
         }else{

            //Recebe o arquivo via POST
            $arquivoTemplate = $_FILES['arquivo']['tmp_name'];

            //Renomeia o arquivo
            $geraBytes    = random_bytes(7);
            $nomeTemplate = bin2hex($geraBytes).'.docx';        

            //Tenta fazer o upload do arquivo
            if(move_uploaded_file($arquivoTemplate,"assets/templateContratos/".$nomeTemplate)){

               //Cria o array com os dados do template do contrato para serem salvos na base de dados
               $dadosTemplate = [
                  'DESCRICAO'       => $_POST['descricao'],
                  'VIGENCIA_INICIO' => $_POST['vigenciaInicio'],
                  'VIGENCIA_FIM'    => $_POST['vigenciaFim'] == '' ? NULL : $_POST['vigenciaFim'],
                  'NOME_TEMPLATE'   => $nomeTemplate,
                  'ATIVO'           => isset($_POST['ativo']) ? 1 : 0 
               ];
               
               //Insere os dados na base e redireciona para a próxima página
               if($template->addTemplateContrato($dadosTemplate))
                  header("Location: ".BASE_URL.'/contratos');
               else
                  header("Location: ".BASE_URL.'/contratos/novoTemplate/EBD');
            }else{
               
               header("Location: ".BASE_URL.'/contratos/novoTemplate/UP');   
            }                              
         }
      }else{
         header("Location: ".BASE_URL.'/contratos/novoTemplate/EXT');    
      }            
   }

   //Função para adicionar um novo contrato
   public function copiaTemplate($error=NULL){ 
      $template = new Models\TemplateContrato();

      $dados = array();

      //Busca os templates ativos para a copia
      $dados['templates'] = $template->listaContratosPlanos(); 

      //Verifica se a variavel error foi inicializada
      if(isset($error))
         $dados['error'] = $error;
      else
         $dados['error'] = NULL;      
      
      //Carrega a view responsável por cadastrar um novo contrato  
      $this->loadView('copiaContrato', $dados);    
   }

   //Função para salvar os dados do template do contrato
   public function copiaTemplateContrato(){
      $template = new Models\TemplateContrato();

      //Busca o template de origem
      $templateOrigem = $template->buscaTemplatePorId($_POST['templateOrigem']);      

      //Cria o array com os dados do template do contrato para serem copiados na base de dados
      $dadosTemplate = [
         'DESCRICAO'       => $_POST['descricao'],
         'VIGENCIA_INICIO' => $_POST['vigenciaInicio'],
         'VIGENCIA_FIM'    => $_POST['vigenciaFim'] == '' ? NULL : $_POST['vigenciaFim'],
         'TEXTO_CONTRATO'  => $templateOrigem['TEXTO_CONTRATO'],
         'ATIVO'           => 1 
      ];
                 
      //print_r($dadosTemplate);die;
      //Insere os dados na base e redireciona para a próxima página
      if($template->addTemplateContrato($dadosTemplate))
         header("Location: ".BASE_URL.'/contratos');
      else
         header("Location: ".BASE_URL.'/contratos/novoTemplate/EBD');                  
      
   }

   //Função para apagar o template do contrato
   public function ApagaTemplate($idTemplate){
      if(!empty($idTemplate)){
         $template = new Models\TemplateContrato();

         //Busca o dados do template para apagar o arquivo do template
         $dadosTemplate = $template->buscaTemplatePorId($idTemplate);

         //Apaga o arquivo
         $this->ApagaArquivoTemplate($dadosTemplate['NOME_TEMPLATE']);

         //Apaga o registro no banco
         $template->ApagaTemplateContrato($idTemplate);
      }
          
      header("Location: ".BASE_URL.'/contratos');
   }   

   //Função para apagar o arquivo com a assinatura do vendedor
   private function ApagaArquivoTemplate($nomeArquivo){
      //define o caminho do arquivo
      $caminho = "assets/templateContratos/".$nomeArquivo;
      //Apaga o arquivo
      unlink($caminho);            
   }
   
}