<?php
namespace Controllers;

use Core, Models;
use Dompdf\Dompdf;
use Dompdf\Options;
use Knp\Snappy\Pdf;

class GeraContratosController extends Core\Controller {
	
    public function __construct() {
   
        $this->isLogged();          //verifica se está logado, estou vendo isso no Core/Controller
        $this->verificaPermissao(); //verifica se tenho permissao, estou vendo isso no Core/Controller		
    }

    //Função para gerar o contrato
    public function geraContrato($idProposta,$tipoPessoa){

    }

    //Função para gerar o contrato PA
    public function geraContratoPA_PF($codigoProposta){
        $proposta = new Models\PropostaPf();

        //Verifica se o cliente é menor de idade para buscar os dados na base
        $cliente = $proposta->verificaClienteMenorIdade($codigoProposta);//print_r($cliente);die;
        
        if($cliente['REPLEGAL'] == "SIM")
            $dados['cliente'] = $proposta->buscaClienteMenor($codigoProposta);
        else
            $dados['cliente'] = $proposta->buscaClienteMaior($codigoProposta);                        
        
        //Prepara as fotos para serem enviadas a view                
        $dados['fotoCabecalho'] = base64_encode(file_get_contents("assets/images/contratos/cabecalho_contrato.png"));
        $dados['fotoRodape'] = base64_encode(file_get_contents("assets/images/contratos/rodape_contrato.png"));
        $dados['assinaturaNicolau'] = base64_encode(file_get_contents("assets/images/contratos/assinatura_dr_nicolau.png"));
        $dados['assinaturaRodrigo'] = base64_encode(file_get_contents("assets/images/contratos/assinatura_dr_rodrigo.png"));

        ob_start();                
        $this->loadViewInTemplate('contratoPA_pf', $dados);
        $html = ob_get_clean();
        //echo $html;die;

        // instancia a classe Dompdf e options        
        $dompdf = new Dompdf();

        //Carrega o html que será utilizado para gerar o pdf        
        $dompdf->loadHtml($html);        

        //Define o tamanho do papel e sua orientação       
        $dompdf->setPaper('A4', 'portrait'); //portrait orientação retrato ## landscape orientação paisagem

        //Converte o HTML para PDF
        $dompdf->render();

        //Gera o PDF
        $dompdf->stream("contrato_PA_PF.pdf", array("Attachment" => false));
    }

    //Função para gerar o contrato PA
    public function geraContratoPA_PJ($codigoProposta){
        $proposta = new Models\PropostaPj();
        
        //Busca os dados que serão exibidos no contrato               
        $dados['empresa'] = $proposta->buscaEmpresaContrato($codigoProposta);
        
        //Prepara a foto do cabeçalho e do rodapé para ser enviada a view                
        $dados['fotoCabecalho'] = base64_encode(file_get_contents("assets/images/contratos/cabecalho_contrato.png"));
        $dados['fotoRodape'] = base64_encode(file_get_contents("assets/images/contratos/rodape_contrato.png"));
        $dados['assinaturaNicolau'] = base64_encode(file_get_contents("assets/images/contratos/assinatura_dr_nicolau.png"));
        $dados['assinaturaRodrigo'] = base64_encode(file_get_contents("assets/images/contratos/assinatura_dr_rodrigo.png"));

        ob_start();                
        $this->loadViewInTemplate('contratoPA_pj', $dados);
        $html = ob_get_clean();
        //echo $html;die;

        // instancia a classe Dompdf e options        
        $dompdf = new Dompdf();

        //Carrega o html que será utilizado para gerar o pdf        
        $dompdf->loadHtml($html);        

        //Define o tamanho do papel e sua orientação       
        $dompdf->setPaper('A4', 'portrait'); //portrait orientação retrato ## landscape orientação paisagem

        //Converte o HTML para PDF
        $dompdf->render();

        //Gera o PDF
        $dompdf->stream("contrato_PA_PJ.pdf", array("Attachment" => false));
    }

    //Função para gerar os contratos das pessoas jurídicas
    /*public function contratoPessoaJuridica($codigoProposta){
        $contrato = new Models\Contratos();

        //Busca os dados do contrato na base
        $dadosContrato = $contrato->buscaDadosContratoPJ($codigoProposta);        

        //Substitui as palavras chaves pelos dados do banco
        $dados['conteudo'] = $this->palavraChaveJuridico($dadosContrato['TEXTO_CONTRATO'],$dadosContrato);       
        //print_r($html);die;

        //Prepara a foto do cabeçalho e do rodapé para ser enviada a view                
        $dados['fotoCabecalho'] = base64_encode(file_get_contents("assets/images/contratos/cabecalho_contrato.png"));
        $dados['fotoRodape'] = base64_encode(file_get_contents("assets/images/contratos/rodape_contrato.png"));
        $dados['titulo'] = "Contrato Pessoa Jurídica";

        //Prepara o cabeçalho, rodapé e o conteúdo do contrato para gerar o PDF              
        ob_start();                
        $this->loadViewInTemplate('contratoCabecalho', $dados);
        $cabecalho = ob_get_clean();
        //echo $cabecalho;die;

        ob_start();                
        $this->loadViewInTemplate('contratoRodape', $dados);
        $rodape = ob_get_clean();
        //echo $rodape;die;

        ob_start();                
        $this->loadViewInTemplate('contratoTemplate', $dados);
        $html = ob_get_clean();
        //echo $html;die;

        //Verifica se o sistema está rodando em produção ou desenvolvimento
        *if(ENVIRONMENT == 'development')
            $snappy = new Pdf('C:\wkhtmltopdf\bin\wkhtmltopdf.exe');
        else*
        //$snappy = new Pdf('/usr/local/bin/wkhtmltopdf');        
        $snappy = new Pdf('C:\wkhtmltopdf\bin\wkhtmltopdf.exe');        

        $options = [
            'orientation'           => 'portrait',                    
            'encoding'              => 'utf-8',
            'margin-top'            => '25',
            'margin-bottom'         => '15',
            'dpi'                   => 120,
            'images'                => true,
            'image-dpi'             => 600,
            'enable-external-links' => true,
            'enable-internal-links' => true,
            'enable-javascript'     => true,
            'header-html'           => $cabecalho,
            'footer-html'           => $rodape,
            //'margin-left'           => '2',
            //'margin-right'          => '2'                               
        ];                

        header('Content-Type: application/pdf');
        header('Content-Disposition: attachment; filename="contrato_pessoa_juridica.pdf"');
        echo $snappy->getOutputFromHtml($html,$options);        
    }*/

    //Função para gerar os contratos das pessoas jurídicas
    public function contratoPessoaJuridica($codigoProposta){
        $contrato = new Models\Contratos();

        //Busca os dados do contrato na base
        $dadosTemplate = $contrato->buscaDadosContratoPJ($codigoProposta);
        //print_r($dadosContrato);die;                         

        $texto = $this->palavraChaveJuridico($dadosTemplate);        
        
        \PhpOffice\PhpWord\Settings::setPdfRendererPath('vendor/dompdf/dompdf');
        \PhpOffice\PhpWord\Settings::setPdfRendererName('DomPDF');

        //Carrega o template em docx
        $templateProcessor = new \PhpOffice\PhpWord\TemplateProcessor('assets/templateContratos/'.$dadosTemplate['NOME_TEMPLATE']);

        $templateProcessor->setValue('${NOME-PLANO}', $texto['NOME-PLANO']);
        $templateProcessor->setValue('${REGISTRO-PRODUTO}', $texto['REGISTRO-PRODUTO']);
        $templateProcessor->setValue('${CONTRATACAO}', $texto['CONTRATACAO']);
        $templateProcessor->setValue('${ABRANGECIA-GEOGRAFICA}', $texto['ABRANGECIA-GEOGRAFICA']);
        $templateProcessor->setValue('${SEGMENTACAO-ASSISTENCIAL}', $texto['SEGMENTACAO-ASSISTENCIAL']);
        $templateProcessor->setValue('${PADRAO-ACOMODACAO}', $texto['PADRAO-ACOMODACAO']);
        $templateProcessor->setValue('${RAZAO-SOCIAL}', $texto['RAZAO-SOCIAL']);
        $templateProcessor->setValue('${NOME-FANTASIA}', $texto['NOME-FANTASIA']);
        $templateProcessor->setValue('${CNPJ}', $texto['CNPJ']);
        $templateProcessor->setValue('${INSCRICAO-ESTADUAL}', $texto['INSCRICAO-ESTADUAL']);
        $templateProcessor->setValue('${INSCRICAO-MUNICIPAL}', $texto['INSCRICAO-MUNICIPAL']);
        $templateProcessor->setValue('${ENDERECO}', $texto['ENDERECO']);
        $templateProcessor->setValue('${NUMERO-ENDERECO}', $texto['NUMERO-ENDERECO']);
        $templateProcessor->setValue('${BAIRRO}', $texto['BAIRRO']);
        $templateProcessor->setValue('${CEP}', $texto['CEP']);
        $templateProcessor->setValue('${MUNICIPIO}', $texto['MUNICIPIO']);
        $templateProcessor->setValue('${UF}', $texto['UF']);
        $templateProcessor->setValue('${NOME-RESPONSAVEL}', $texto['NOME-RESPONSAVEL']);
        $templateProcessor->setValue('${CPF-RESPONSAVEL}', $texto['CPF-RESPONSAVEL']);
        $templateProcessor->setValue('${RG-RESPONSAVEL}', $texto['RG-RESPONSAVEL']);
        $templateProcessor->setValue('${TELEFONE-CONTATO}', $texto['TELEFONE-CONTATO']);
        $templateProcessor->setValue('${EMAIL-CONTATO}', $texto['EMAIL-CONTATO']);
        $templateProcessor->setValue('${NOME-FUNCIONARIO}', $texto['NOME-FUNCIONARIO']);
        $templateProcessor->setValue('${TELEFONE-FUNCIONARIO}', $texto['TELEFONE-FUNCIONARIO']);
        $templateProcessor->setValue('${EMAIL-FUNCIONARIO}', $texto['EMAIL-FUNCIONARIO']);
        $templateProcessor->setValue('${DATA-EXTENSO}', $texto['DATA-EXTENSO']);                
        
        //$templateProcessor->cloneBlock('CONTRATO', count($dadosContrato), true, false, $dadosContrato);
        
        $templateProcessor->saveAs("assets/contratos/juridico-contrato.docx");

        $fileStream = fopen("assets/contratos/juridico-contrato.docx",'r');
        
        $phpWord   = \PhpOffice\PhpWord\IOFactory::load("assets/contratos/juridico-contrato.docx");
        $phpWriter = \PhpOffice\PhpWord\IOFactory::createWriter($phpWord,'PDF');        
        $phpWriter->save("assets/contratos/contrato-juridico.pdf"); // Save to PDF

        unlink("assets/contratos/juridico-contrato.docx");

        // Configuramos os headers que serão enviados para o browser
        header('Content-Description: File Transfer');
        header('Content-Disposition: attachment; filename="contrato-juridico.pdf"');
        header('Content-Type: application/pdf');
        header('Content-Transfer-Encoding: binary');
        header('Content-Length: ' . filesize('assets/contratos/contrato-juridico.pdf'));        
        
        // Envia o arquivo para o cliente
        readfile('assets/contratos/contrato-juridico.pdf');

        unlink("assets/contratos/contrato-juridico.pdf");
       
    }

    //Função para gerar os contratos das pessoas físicas
    /*public function contratoPessoaFisica($codigoProposta){
        $contrato = new Models\Contratos();
        $proposta = new Models\PropostaPf();

        //Verifica se o cliente é menor de idade para buscar os dados na base
        $cliente = $proposta->verificaClienteMenorIdade($codigoProposta);//print_r($cliente);die;
        
        if($cliente['REPLEGAL'] == "SIM")
            $dadosContrato = $contrato->buscaDadosContratoPFMenor($codigoProposta);
        else
            $dadosContrato = $contrato->buscaDadosContratoPFMaior($codigoProposta);                

        //print_r($dadosContrato);die;
        //Substitui as palavras chaves pelos dados do banco
        $dados['conteudo'] = $this->palavraChaveFisica($dadosContrato['TEXTO_CONTRATO'],$dadosContrato);       
        //print_r($conteudo);die;

        //Prepara a foto do cabeçalho e do rodapé para ser enviada a view                
        $dados['fotoCabecalho'] = base64_encode(file_get_contents("assets/images/contratos/cabecalho_contrato.png"));
        $dados['fotoRodape'] = base64_encode(file_get_contents("assets/images/contratos/rodape_contrato.png"));
        $dados['titulo'] = "Contrato Pessoa Física";

        //Prepara o cabeçalho, rodapé e o conteúdo do contrato para gerar o PDF              
        ob_start();                
        $this->loadViewInTemplate('contratoCabecalho', $dados);
        $cabecalho = ob_get_clean();
        //echo $cabecalho;die;

        ob_start();                
        $this->loadViewInTemplate('contratoRodape', $dados);
        $rodape = ob_get_clean();
        //echo $rodape;die;

        ob_start();                
        $this->loadViewInTemplate('contratoTemplate', $dados);
        $html = ob_get_clean();
        //echo $html;die;

        //Verifica se o sistema está rodando em produção ou desenvolvimento
        *if(ENVIRONMENT == 'development')
            $snappy = new Pdf('C:\wkhtmltopdf\bin\wkhtmltopdf.exe');
        else*
        //$snappy = new Pdf('/usr/local/bin/wkhtmltopdf');        
        $snappy = new Pdf('C:\wkhtmltopdf\bin\wkhtmltopdf.exe');        

        $options = [
            'orientation'           => 'portrait',                    
            'encoding'              => 'utf-8',
            'margin-top'            => '25',
            'dpi'                   => 120,
            'images'                => true,
            'image-dpi'             => 600,
            'enable-external-links' => true,
            'enable-internal-links' => true,
            'enable-javascript'     => true,
            'header-html'           => $cabecalho,
            'footer-html'           => $rodape,
            //'margin-left'           => '2',
            //'margin-right'          => '2'                               
        ];                

        header('Content-Type: application/pdf');
        header('Content-Disposition: attachment; filename="contrato_pessoa_juridica.pdf"');
        echo $snappy->getOutputFromHtml($html,$options);        
    }*/

    //Função para gerar os contratos das pessoas físicas
    public function contratoPessoaFisica($codigoProposta){
        $contrato = new Models\Contratos();
        $proposta = new Models\PropostaPf();

        //Verifica se o cliente é menor de idade para buscar os dados na base
        $cliente = $proposta->verificaClienteMenorIdade($codigoProposta);//print_r($cliente);die;
        
        if($cliente['REPLEGAL'] == "SIM")
            $dadosContrato = $contrato->buscaDadosContratoPFMenor($codigoProposta);
        else
            $dadosContrato = $contrato->buscaDadosContratoPFMaior($codigoProposta);                

        print_r($dadosContrato);die;

        $texto = $this->palavraChaveJuridico($dadosTemplate);        
        
        \PhpOffice\PhpWord\Settings::setPdfRendererPath('vendor/dompdf/dompdf');
        \PhpOffice\PhpWord\Settings::setPdfRendererName('DomPDF');

        //Carrega o template em docx
        $templateProcessor = new \PhpOffice\PhpWord\TemplateProcessor('assets/templateContratos/'.$dadosTemplate['NOME_TEMPLATE']);

        $templateProcessor->setValue('${NOME-PLANO}', $texto['NOME-PLANO']);
        $templateProcessor->setValue('${REGISTRO-PRODUTO}', $texto['REGISTRO-PRODUTO']);
        $templateProcessor->setValue('${CONTRATACAO}', $texto['CONTRATACAO']);
        $templateProcessor->setValue('${ABRANGECIA-GEOGRAFICA}', $texto['ABRANGECIA-GEOGRAFICA']);
        $templateProcessor->setValue('${SEGMENTACAO-ASSISTENCIAL}', $texto['SEGMENTACAO-ASSISTENCIAL']);
        $templateProcessor->setValue('${PADRAO-ACOMODACAO}', $texto['PADRAO-ACOMODACAO']);
        $templateProcessor->setValue('${NOME}', $texto['NOME']);
        $templateProcessor->setValue('${MAENOME}', $texto['MAENOME']);
        $templateProcessor->setValue('${PAINOME}', $texto['PAINOME']);
        $templateProcessor->setValue('${NASCIMENTO}', $texto['NASCIMENTO']);
        $templateProcessor->setValue('${CPF}', $texto['CPF']);
        $templateProcessor->setValue('${RG}', $texto['RG']);
        $templateProcessor->setValue('${ORGAO-EXPEDIDOR}', $texto['ORGAO-EXPEDIDOR']);
        $templateProcessor->setValue('${ENDERECO}', $texto['ENDERECO']);
        $templateProcessor->setValue('${NUMERO-ENDERECO}', $texto['NUMERO-ENDERECO']);
        $templateProcessor->setValue('${BAIRRO}', $texto['BAIRRO']);
        $templateProcessor->setValue('${CEP}', $texto['CEP']);
        $templateProcessor->setValue('${MUNICIPIO}', $texto['MUNICIPIO']);
        $templateProcessor->setValue('${UF}', $texto['UF']);       
        $templateProcessor->setValue('${TELEFONE-CONTATO}', $texto['TELEFONE-CONTATO']);
        $templateProcessor->setValue('${EMAIL-CONTATO}', $texto['EMAIL-CONTATO']);
        $templateProcessor->setValue('${BENEFICIARIO-TITULAR}', $texto['BENEFICIARIO-TITULAR']);
        $templateProcessor->setValue('${TITULAR-CPF}', $texto['TITULAR-CPF']);        
        $templateProcessor->setValue('${DATA-EXTENSO}', $texto['DATA-EXTENSO']);                
        
        //$templateProcessor->cloneBlock('CONTRATO', count($dadosContrato), true, false, $dadosContrato);
        
        $templateProcessor->saveAs("assets/contratos/fisica-contrato.docx");

        $fileStream = fopen("assets/contratos/fisica-contrato.docx",'r');
        
        $phpWord   = \PhpOffice\PhpWord\IOFactory::load("assets/contratos/fisica-contrato.docx");
        $phpWriter = \PhpOffice\PhpWord\IOFactory::createWriter($phpWord,'PDF');        
        $phpWriter->save("assets/contratos/contrato-fisica.pdf"); // Save to PDF

        unlink("assets/contratos/fisica-contrato.docx");

        // Configuramos os headers que serão enviados para o browser
        header('Content-Description: File Transfer');
        header('Content-Disposition: attachment; filename="contrato-fisica.pdf"');
        header('Content-Type: application/pdf');
        header('Content-Transfer-Encoding: binary');
        header('Content-Length: ' . filesize('assets/contratos/contrato-fisica.pdf'));        
        
        // Envia o arquivo para o cliente
        readfile('assets/contratos/contrato-fisica.pdf');

        unlink("assets/contratos/contrato-fisica.pdf");
    }

    //Função para substituir as palavras chaves pelos dados do banco de dados
    private function palavraChaveJuridico($dadosTemplate){
        //Substitui as variáveis do template pelo dados do banco
        setlocale(LC_TIME, 'pt_BR', 'pt_BR.utf-8', 'pt_BR.utf-8', 'portuguese');
        date_default_timezone_set('America/Sao_Paulo');
        $dataPorExtenso = utf8_encode(strftime('%d de %B de %Y', strtotime('today')));

        //Efetua a substituição das palavras chaves pelos dados do banco
        $texto = [
            "NOME-PLANO"               => $dadosTemplate['NOMEPLANO'],
            "REGISTRO-PRODUTO"         => $dadosTemplate['REG_ANS'],
            "CONTRATACAO"              => $dadosTemplate['TIPO_CONTRATO'],
            "ABRANGECIA-GEOGRAFICA"    => $dadosTemplate['ABRANGENCIA'],
            "SEGMENTACAO-ASSISTENCIAL" => $dadosTemplate['SEGMENTACAO_ASSISTENCIAL'],
            "PADRAO-ACOMODACAO"        => $dadosTemplate['ACOMODACAO'],
            "RAZAO-SOCIAL"             => $dadosTemplate['RAZAO_SOCIAL'],
            "NOME-FANTASIA"            => $dadosTemplate['NOME_FANTASIA'],
            "CNPJ"                     => $dadosTemplate['CNPJ'],
            "INSCRICAO-ESTADUAL"       => $dadosTemplate['INSCR_ESTADUAL'], 
            "INSCRICAO-MUNICIPAL"      => $dadosTemplate['INSCR_MUNICIPAL'],
            "ENDERECO"                 => $dadosTemplate['ENDERECO'],
            "NUMERO-ENDERECO"          => $dadosTemplate['NUMERO'],
            "BAIRRO"                   => $dadosTemplate['BAIRRO'],
            "CEP"                      => $dadosTemplate['CEP'], 
            "MUNICIPIO"                => $dadosTemplate['CIDADE'],
            "UF"                       => $dadosTemplate['UF'],
            "NOME-RESPONSAVEL"         => $dadosTemplate['NOME_REP'],
            "CPF-RESPONSAVEL"          => $dadosTemplate['CPF_REP'],
            "RG-RESPONSAVEL"           => $dadosTemplate['RG_REP'],
            "TELEFONE-CONTATO"         => $dadosTemplate['FONE'],
            "EMAIL-CONTATO"            => mb_strtolower($dadosTemplate['EMAIL']),
            "NOME-FUNCIONARIO"         => $dadosTemplate['NOME_CONT'],
            "TELEFONE-FUNCIONARIO"     => $dadosTemplate['FONE_CONT'],
            "EMAIL-FUNCIONARIO"        => $dadosTemplate['EMAIL_CONT'],
            "DATA-EXTENSO"             => $dataPorExtenso
        ];

        return $texto;
    }

    //Função para substituir as palavras chaves pelos dados do banco de dados
    private function palavraChaveFisica($dadosTemplate){
        //INFORMA A DATA POR EXTENSO
        setlocale(LC_TIME, 'pt_BR', 'pt_BR.utf-8', 'pt_BR.utf-8', 'portuguese');
        date_default_timezone_set('America/Sao_Paulo');
        $dataPorExtenso = utf8_encode(strftime('%d de %B de %Y', strtotime('today')));        

        //Efetua a substituição das palavras chaves pelos dados do banco
        $texto = [
            "NOME-PLANO"               => $dadosTemplate['NOMEPLANO'],
            "REGISTRO-PRODUTO"         => $dadosTemplate['REG_ANS'],
            "CONTRATACAO"              => $dadosTemplate['TIPO_CONTRATO'],
            "ABRANGECIA-GEOGRAFICA"    => $dadosTemplate['ABRANGENCIA'],
            "SEGMENTACAO-ASSISTENCIAL" => $dadosTemplate['SEGMENTACAO_ASSISTENCIAL'],
            "PADRAO-ACOMODACAO"        => $dadosTemplate['ACOMODACAO'],
            "NOME"                     => $dadosTemplate['NOME'],
            "MAENOME"                  => $dadosTemplate['NOMEMAE'],
            "PAINOME"                  => $dadosTemplate['NOMEPAI'],
            "NASCIMENTO"               => $dadosTemplate['NASCIMENTO'],
            "CPF"                      => $dadosTemplate['CPF'],
            "RG"                       => $dadosTemplate['RG'],
            "ORGAO-EXPEDIDOR"          => $dadosTemplate['ORGAOEXP'],
            "ENDERECO"                 => $dadosTemplate['ENDERECO'],            
            "NUMERO-ENDERECO"          => $dadosTemplate['NUMERO'],
            "BAIRRO"                   => $dadosTemplate['BAIRRO'],
            "CEP"                      => $dadosTemplate['CEP'], 
            "MUNICIPIO"                => $dadosTemplate['CIDADE'],
            "UF"                       => $dadosTemplate['UF'],
            "TELEFONE-CONTATO"         => $dadosTemplate['FONE'],
            "EMAIL-CONTATO"            => mb_strtolower($dadosTemplate['EMAIL']),
            "BENEFICIARIO-TITULAR"     => $dadosTemplate['BENEFICIARIOTITULAR'],
            "TITULAR-CPF"              => $dadosTemplate['TITULARCPF'],
            "DATA-EXTENSO"             => $dataPorExtenso    
        ];        

        return $texto;
    }

}